# Data Quality Tool - dqt

A tool to monitor and test your data.

# Installation

    pip install dqt


# Publishing

https://www.digitalocean.com/community/tutorials/how-to-publish-python-packages-to-pypi-using-poetry-on-ubuntu-22-04
